@@ -89,7 +89,7 @@ Lum::Object* GenerateDialog::GetContent()
                                levelsModel);
 
   label->AddLabel(_(L"POINTS_MIN",L"Min. Points:"),
-                  Lum::OS::display->GetBehaviour()->GetOneOfManyControl(levelDef,true,false));
+                  Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(levelDef,true,false));
 
   return label;
 }
